"use strict";
// Copyright IBM Corp. 2018,2020. All Rights Reserved.
// Node module: @loopback/example-todo-list
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
exports.TodoListTodoController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
let TodoListTodoController = class TodoListTodoController {
    constructor(todoListRepo) {
        this.todoListRepo = todoListRepo;
    }
    async create(id, todo) {
        return this.todoListRepo.todos(id).create(todo);
    }
    async find(id, filter) {
        return this.todoListRepo.todos(id).find(filter);
    }
    async patch(id, todo, where) {
        return this.todoListRepo.todos(id).patch(todo, where);
    }
    async delete(id, where) {
        return this.todoListRepo.todos(id).delete(where);
    }
};
tslib_1.__decorate([
    rest_1.post('/todo-lists/{id}/todos', {
        responses: {
            '200': {
                description: 'TodoList.Todo model instance',
                content: { 'application/json': { schema: rest_1.getModelSchemaRef(models_1.Todo) } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Todo, {
                    title: 'NewTodoInTodoList',
                    exclude: ['id'],
                    optional: ['todoListId'],
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TodoListTodoController.prototype, "create", null);
tslib_1.__decorate([
    rest_1.get('/todo-lists/{id}/todos', {
        responses: {
            '200': {
                description: "Array of Todo's belonging to TodoList",
                content: {
                    'application/json': {
                        schema: { type: 'array', items: rest_1.getModelSchemaRef(models_1.Todo) },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.param.query.object('filter')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TodoListTodoController.prototype, "find", null);
tslib_1.__decorate([
    rest_1.patch('/todo-lists/{id}/todos', {
        responses: {
            '200': {
                description: 'TodoList.Todo PATCH success count',
                content: { 'application/json': { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Todo, { partial: true }),
            },
        },
    })),
    tslib_1.__param(2, rest_1.param.where(models_1.Todo)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, Object, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TodoListTodoController.prototype, "patch", null);
tslib_1.__decorate([
    rest_1.del('/todo-lists/{id}/todos', {
        responses: {
            '200': {
                description: 'TodoList.Todo DELETE success count',
                content: { 'application/json': { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.param.where(models_1.Todo)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TodoListTodoController.prototype, "delete", null);
TodoListTodoController = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.TodoListRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.TodoListRepository])
], TodoListTodoController);
exports.TodoListTodoController = TodoListTodoController;
//# sourceMappingURL=todo-list-todo.controller.js.map